"""
    SatNOGS DB

    SatNOGS DB is a crowdsourced database of details about orbital                     satellites and data collected from them.  # noqa: E501

    The version of the OpenAPI document: 1.1
    Contact: dev@satnogs.org
    Generated by: https://openapi-generator.tech
"""


import unittest

import satnogsdbapiclient
from satnogsdbapiclient.api.artifacts_api import ArtifactsApi  # noqa: E501


class TestArtifactsApi(unittest.TestCase):
    """ArtifactsApi unit test stubs"""

    def setUp(self):
        self.api = ArtifactsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_artifacts_create(self):
        """Test case for artifacts_create

        """
        pass

    def test_artifacts_list(self):
        """Test case for artifacts_list

        """
        pass

    def test_artifacts_retrieve(self):
        """Test case for artifacts_retrieve

        """
        pass


if __name__ == '__main__':
    unittest.main()
