# flake8: noqa

"""
    SatNOGS DB

    SatNOGS DB is a crowdsourced database of details about orbital                     satellites and data collected from them.  # noqa: E501

    The version of the OpenAPI document: 1.1
    Contact: dev@satnogs.org
    Generated by: https://openapi-generator.tech
"""


__version__ = "1.0.0"

# import ApiClient
from satnogsdbapiclient.api_client import ApiClient

# import Configuration
from satnogsdbapiclient.configuration import Configuration

# import exceptions
from satnogsdbapiclient.exceptions import OpenApiException
from satnogsdbapiclient.exceptions import ApiAttributeError
from satnogsdbapiclient.exceptions import ApiTypeError
from satnogsdbapiclient.exceptions import ApiValueError
from satnogsdbapiclient.exceptions import ApiKeyError
from satnogsdbapiclient.exceptions import ApiException
