"""
    SatNOGS DB

    SatNOGS DB is a crowdsourced database of details about orbital                     satellites and data collected from them.  # noqa: E501

    The version of the OpenAPI document: 1.1
    Contact: dev@satnogs.org
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import satnogsdbapiclient
from satnogsdbapiclient.model.telemetry import Telemetry
globals()['Telemetry'] = Telemetry
from satnogsdbapiclient.model.paginated_telemetry_list import PaginatedTelemetryList


class TestPaginatedTelemetryList(unittest.TestCase):
    """PaginatedTelemetryList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPaginatedTelemetryList(self):
        """Test PaginatedTelemetryList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PaginatedTelemetryList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
